@@ -641,6 +641,55 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
+    def get_hk_deri_daily_market_report(self, deri, code ,start_date, end_date, exp = 'current'):
+
+        check_bool_dict = self.check_hk_deri_daily_market_report_args(deri, code ,start_date, end_date, exp)
+
+        if False not in list(check_bool_dict.values()):
+            #link_url = 'http://localhost:8000/data_api?'
+            link_url = 'http://www.hkfdb.net/data_api?'
+            token_str = 'token=' + str(self.authToken)
+            deri_str = 'deri=' + deri
+            code_str = 'code=' + code
+            exp_str = 'exp=' + exp
+            database_str = 'database=' + 'hk_deri_daily_market_report'
+            start_date_str = 'start_date=' + str(start_date)
+            end_date_str = 'end_date=' + str(end_date)
+            link_str = link_url + '&' + token_str + '&' + database_str \
+                       + '&' + start_date_str + '&' + end_date_str\
+                       + '&' + deri_str  + '&' + code_str  + '&' + exp_str
+            
+            response = requests.get(link_str)
+            result = ast.literal_eval(json.loads(response.content))
+
+            df = pd.DataFrame(result)
+
+            df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
+            
+            if deri == 'opt':            
+                df['year_month'] = pd.to_datetime(df['year_month'], format='%b%y')
+                df = df.sort_values(by=['date','year_month'])
+                df['year_month'] = df['year_month'].dt.strftime('%b-%y')
+                cols = list(df.columns)
+                cols = [cols[-1]] + cols[:-1]
+                df = df[cols]
+
+            elif deri == 'fut':
+                df = df.sort_values(by='date')
+
+            df = df.reset_index(drop=True)
+            
+            return df
+
+        else:
+            err_msg = 'Error in: '
+            for error in check_bool_dict:
+                if check_bool_dict[error] == False:
+                    err_msg += error + ','
+            print(err_msg)
+            
+    #########################################################################################
+
     def check_hk_stock_ohlc_args(self, code, start_date, end_date, freq):
         freq_list = ['1T', '5T', '15T', '30T', '1D']
         freq_valid = True if freq in freq_list else False
@@ -1059,3 +1108,79 @@ class Database:
             'exceed_max_day_diff':exceed_max_day_diff}
 
         return check_bool_dict
+
+    def check_hk_deri_daily_market_report_args(self, deri, code, start_date, end_date, exp):
+
+        if deri == 'fut':
+            deri_type = True
+        elif deri == 'opt':
+            deri_type = True
+        else:
+            deri_type = False
+
+        if exp == 'current':
+            exp_type = True
+        elif exp == 'next':
+            exp_type = True
+        else:
+            exp_type = False
+
+        try:
+            code_length = len(code) > 0
+        except:
+            code_length = False
+        try:
+            start_date_is_int = isinstance(start_date, int)
+        except:
+            start_date_is_int = False
+        try:
+            start_date_length = len(str(start_date)) == 8
+        except:
+            start_date_length = False
+        try:
+            start_date_future = datetime.datetime.strptime(str(start_date),
+                                                           '%Y%m%d').date() <= datetime.datetime.now().date()
+        except:
+            start_date_future = False
+        try:
+            end_date_is_int = isinstance(end_date, int)
+        except:
+            end_date_is_int = False
+        try:
+            end_date_length = len(str(end_date)) == 8
+        except:
+            end_date_length = False
+        try:
+            end_date_future = datetime.datetime.strptime(str(end_date),
+                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
+        except:
+            end_date_future = False
+        try:
+            end_after_start_date = datetime.datetime.strptime(str(end_date),
+                                                              '%Y%m%d').date() >= datetime.datetime.strptime(
+                str(start_date), '%Y%m%d').date()
+        except:
+            end_after_start_date = False
+
+        try:
+            day_diff = (datetime.datetime.strptime(str(end_date), '%Y%m%d').date() - \
+                        datetime.datetime.strptime(str(start_date), '%Y%m%d').date()).days
+            exceed_max_day_diff = (deri == 'opt' and day_diff <= 36) or \
+                                  (deri == 'fut' and day_diff <= 2160)
+        except:
+            exceed_max_day_diff = False
+
+        check_bool_dict = {'code_length': code_length,
+                           'start_date_length': start_date_length,
+                           'start_date_is_int': start_date_is_int,
+                           'start_date_future': start_date_future,
+                           'end_date_is_int': end_date_is_int,
+                           'end_date_length': end_date_length,
+                           'end_date_future': end_date_future,
+                           'end_after_start_date': end_after_start_date,
+                           'exceed_max_day_diff': exceed_max_day_diff,
+                           'deri_type': deri_type,
+                           'exp_type': exp_type}
+
+        return check_bool_dict
+
